@@ -142,10 +142,14 @@ def thumbnail(image, size):
     if create_new:
         pil_image = Image.open(file)
         pil_format = pil_image.format or 'JPEG'
+        if pil_format not in Image.SAVE:
+            pil_format = 'JPEG'
         if shift is not None:
             shorter = min(image.width, image.height)
             pil_image = pil_image.crop((shift, 0, shorter+shift, shorter))
         pil_image.thumbnail((width, height), Image.ANTIALIAS)
+        if pil_format == 'JPEG' and pil_image.mode != 'RGB':
+            pil_image = pil_image.convert('RGB')
         pil_image.save(thumb_filename, pil_format)
 
     return thumb_url
